function shapelets_concatenate_shapecats,shapecat1,shapecat2

;$Id: shapelets_concatenate_shapecats.pro, v2$
;
; Copyright  2004 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
;
;+
; NAME:
;      SHAPELETS_CONCATENATE_SHAPECATS
;
; CATEGORY:
;      Shapelets.
;
; PURPOSE:
;      Concatenates two (IDL shapecat structure) catalogues.
;
; INPUTS:
;      shapecat1 - Shapelet catalogue structure. 
;      shapecat2 - Shapelet catalogue structure. 
;
; OPTIONAL INPUTS:
;      none.
;
; KEYWORD PARAMETERS:
;      none.
;
; OUTPUTS:
;      shapecat  - Shapelet catalogue structure, containing objects from both
;                  of the input catalogues.
;
; NOTES: 
;      The two catalogues need to have the same n_max, and be both in polar or
;      both in Cartesian shapelets.
;
; MODIFICATION HISTORY:
;      May 04 - Converted to use arbitrary number of catalogue fields by RM
;      Apr 04 - Written by R. Massey
;-

COMPILE_OPT idl2


; Check to see the two catalogues are compatible (makes things much simpler later on)
if (shapecat1.maxn_max ne shapecat2.maxn_max) then message, $
  "The two catalogues are not to the same n_max and are therefore not compatible!"
if ((shapecat1.polar+shapecat2.polar) mod 2 ne 0) then message, $
  "One catalogue contains polar shapelets, and the other contains Cartesian shapelets. They are therefore not compatible!"
n1=n_tags(shapecat1)
n2=n_tags(shapecat2)
if (n1 ne n2) then message, $
  "The two catalogues do not contain the same number of tags and are therefore not compatible!"
n=n1
names1=tag_names(shapecat1)
names2=tag_names(shapecat2)
;if (total(names1 eq names2) ne n) then message, $ ; faster version?
for i=0,n-1 do if (names1[i] ne names2[i]) then message, $
  "The two catalogues' tags do not match, so they are therefore not compatible"
names=names1


; Begin a new (combined) catalogue
shapecat={name:shapecat1.name+"_and_"+shapecat2.name, type:"shapecat"} 
has_history=0B


; Compile a concatenated list of variables
for i=0,n-1 do begin
  case strupcase(names[i]) of
    "NAME":
    "TYPE":
    "HISTORY": begin
                 shapecat=create_struct(shapecat,"history",[shapecat1.history,"Concatenated with "+shapecat2.history])
                 has_history=1B
               end
    "N": shapecat=create_struct(shapecat,"n",long(shapecat1.n)+long(shapecat2.n))
    "N_COEFFS": shapecat=create_struct(shapecat,"n_coeffs",shapecat1.n_coeffs)
    "MAXN_MAX": shapecat=create_struct(shapecat,"maxn_max",shapecat1.maxn_max)
    "SEEING": shapecat=create_struct(shapecat,"seeing",(shapecat1.seeing+shapecat2.seeing)/2.)
    "POLAR": shapecat=create_struct(shapecat,"polar",shapecat1.polar)
    "MOMENTS": shapecat=create_struct(shapecat,"moments",shapecat1.moments)
    "SEXTRACTOR": shapecat=create_struct(shapecat,"sextractor",shapecat1.sextractor)
    else: shapecat=create_struct(shapecat,names[i],[shapecat1.(i),shapecat2.(i)])
  endcase
endfor


; Add remark to object's history
;if has_history eq 0B then shapecat=create_struct(shapecat,"history",[shapecat1.name,"Concatenated with "+shapecat2.name])


return,shapecat

end
