function shapelets_add,decomp_in1,decomp_in2

;$Id: shapelets_add.pro, v2$
;
; Copyright  2004 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
;
;+
; NAME:
;      SHAPELETS_ADD
;
; CATEGORY:
;      Shapelets.
;
; PURPOSE:
;      Adds together two images (stored as shapelet decompositions).
;
; INPUTS:
;      DECOMP_IN1 - A Cartesian shapelet decomposition.
;      DECOMP_IN2 - A Cartesian shapelet decomposition.
;
; OPTIONAL INPUTS:
;      None.
;
; KEYWORD PARAMETERS:
;      None.
;
; OUTPUTS:
;      DECOMP_OUT - A Cartesian shapelet decomposition, DECOMP_IN1+DECOMP_IN2.
;
; NOTES:
;      Assumes all sorts of things like the same beta, pixellisation: only
;      useful for comparing one object before & after an operation.
;
; MODIFICATION HISTORY:
;      Apr 02 - Writen by Richard Massey
;-

; Copy decomp structure
decomp_out=decomp_in1

; Add the other's shapelet coefficients (the model is linear)
decomp_out.coeffs=decomp_in1.coeffs-decomp_in2.coeffs

; Do the same to the (statistically independent) errors on the coefficients
decomp_out.coeffs_error=decomp_out.coeffs*sqrt((decomp_in1.coeffs_error/decomp_in1.coeffs)^2+(decomp_in2.coeffs_error/decomp_in2.coeffs)^2)

; Return answer
return,decomp_out

end

