pro plt_objs,pstamp,decomp,$
             image_in=image_in,scat_in=scat_in,focus=focus

; July 2004 - Modified by AR to allow more flexibility in indexing
; August 2003 - Written by A. refregier
; 
; PURPOSE: plot objects and their decomposition
; INPUT: pstamp: postage stamp from shapelets_sexcat2pstamp.pro
;        decomp: shapelet decomp structure from mk_decomp.pro 
; KEYWORDS: image_in: input image to plot as well (eg. noise
;                      free simulated image) 
;           scat_in: input sextractor catalog to plot input ellipse as well 
;           focus: focus history structure from shapelets_focus.pro
; OUTPUT: plots

; declarations
dist_max=5.         ; matching radius for input scat comparison [pixels]
c_ran=[min(pstamp.image),max(pstamp.image)]     ; colar bar range
wsize=[525,550]    ; window x and y sizes
dsize=[1000,1200]   ; display size
th_max=focus.beta*sqrt(focus.nmax+1.)
th_min=focus.beta/sqrt(focus.nmax+1.)
th_maxmax=abs(min([focus.x0(0),$  ; imposed by image boundaries
     pstamp.im_ran(1)-pstamp.im_ran(0)-focus.x0(0),$ 
     focus.x0(1),pstamp.im_ran(3)-pstamp.im_ran(2)-focus.x0(1)]))
flag_pstamp=['OK','','nearby object','severe overlap','near edge',$
             'FWHM=0','no backgd','object masked out']
flag_focus=['OK','!7h!6!imin!n-!7h!6!imax!n bounce','max n!imax!n reached',$
            'converged by flatness','failed to converge',$
            'centroid off edge','fatal error']

; plot the original image
window,0,title="Original object",$
  xsize=wsize(0),ysize=wsize(1),xpos=0,ypos=dsize(1)-wsize(1)
plt_pstamp,pstamp,cran=c_ran,title='Original object',/mask

; plot histogram
window,4,title='Histogram',$
    xsize=wsize(0),ysize=300,xpos=0,ypos=dsize(1)-wsize(1)-325 
!p.region=0
gd=where(pstamp.seg ne -1)
im_ran=c_ran
binsize=(im_ran(1)-im_ran(0))/50
plothist,pstamp.image(gd),bin=binsize,$
   xran=c_ran,/xsty,$
   xtitle='pixel value',ytitle='No of pixels',title='Postage stamp histogram'
plothist,pstamp.image(where(pstamp.seg eq 0)),lines=2,/over,bin=binsize
;plothist,pstamp.image(where(pstamp.seg gt 0)),lines=3,/over,bin=binsize
oplot,pstamp.back_mean_local*[1.,1.],[0.,1e6],lines=2
oplot,pstamp.back_mean_local-pstamp.back_rms_local*[1.,1.],[0.,1e6],lines=2
oplot,pstamp.back_mean_local+pstamp.back_rms_local*[1.,1.],[0.,1e6],lines=2
oplot,pstamp.back_mean_local-pstamp.back_rms*[1.,1.],[0.,1e6],lines=1
oplot,pstamp.back_mean_local+pstamp.back_rms*[1.,1.],[0.,1e6],lines=1
xyouts,.45,.85,/norm,charsize=1.7,$
        'loc back ave= '+string(pstamp.back_mean_local,format='(e8.2)')+'!c'+$
        'loc back rms= '+string(pstamp.back_rms_local,format='(e8.2)')+'!c'+$
        'ext back rms= '+string(pstamp.back_rms,format='(e8.2)')


; plot the reconstructed image
shapelets_recomp,decomp,recomp
window,1,title="Shapelets reconstruction",$
  xsize=wsize(0),ysize=wsize(1),xpos=wsize(0)+8,ypos=dsize(1)-wsize(1)
plt_image,recomp,/fr,/col,cran=c_ran,title='Reconstructed object'
plt_ellipse,pstamp.xo,pstamp.yo,$                 ; Sextractor ellipse
    pstamp.a,pstamp.b,(pstamp.theta+90.)/!radeg,lines=2
if keyword_set(focus) then begin ; plot focus history if available
  oplot,[focus.x0(0)],[focus.x0(1)],psym=6       ; final 
  oplot,focus.x0_h(0,*),focus.x0_h(1,*)          ; history
  oplot,[focus.x0_guess(0)],[focus.x0_guess(1)],psym=1; guess
endif
shapelets_moments,decomp,dmom  ; reconstructed moments
plt_ellipse,decomp.x(0),decomp.x(1),dmom.a,dmom.b,dmom.alpha-!pi/2.
oplot,[dmom.xc(0)],[dmom.xc(1)],psym=1

; plot focus history if available
if keyword_set(focus) then begin
  window,3,title="Focus history",$
    xsize=wsize(0),ysize=300,xpos=wsize(0)+8,ypos=dsize(1)-wsize(1)-325
  !p.region=0
  beta_ran=[0.,th_maxmax]
  nmax_ran=[0,max(focus.nmax_h)+2]
  plot,focus.nmax_h,focus.beta_h,/nodata,yran=beta_ran,xran=nmax_ran,$
    xtitle='!6n!imax!n',ytitle='!7b!6',title='Focus history'
  oplot,focus.nmax_h,focus.beta_h
  oplot,focus.nmax_h,focus.beta_h,psym=1
  oplot,[focus.nmax_guess],[focus.beta_guess],psym=7
  oplot,[focus.nmax],[focus.beta],psym=6
  flux=shapelets_flux(decomp,/error)
  snr=flux(0)/flux(1)
  xyouts,.4,.85,/normal,charsize=1.7,$
       '!7b!6='+string(focus.beta,format='(f6.2)')+', '+$
       'n!imax!n='+string(focus.nmax,format='(i2)')+'!c'+$
       '!7v!6!e2!n='+string(focus.chi2,format='(f7.3)')+', '+$
       'snr='+string(snr,format='(f6.1)')+'!c'+$
       'pstamp: '+string(flag_pstamp(pstamp.flag))+'!c'+$
       'focus: '+string(flag_focus(focus.flag))
  ; plot geometrical constraints
  nnmax=xgen(0.,nmax_ran(1)+4)
  oplot,nnmax,focus.th_min*sqrt(nnmax+1.),lines=3
  oplot,nnmax,th_maxmax/sqrt(nnmax+1.),lines=3
endif

; plot object profile
mk_improfile,pstamp.image,prof,x0=decomp.x
window,6,title='Profile'
plot,prof.r,prof.f,yran=c_ran,/ystyle,psym=6,$
  xtitle='r (pixels)',ytitle='I(r)',title='Profile'
oplot,[0,1000],pstamp.back_mean_local*[1.,1.],lines=2
oplot,[0,1000],pstamp.back_mean_local-pstamp.back_rms_local*[1.,1.],lines=1
oplot,[0,1000],pstamp.back_mean_local+pstamp.back_rms_local*[1.,1.],lines=1
r=xgen(0.,max(prof.r))
oplot,r,shapelets_profile(decomp,r),lines=0
if keyword_set(image_in) then begin   ; plot input porfile if available
  bit_ref=image_in.image(pstamp.im_ran(0):pstamp.im_ran(1),$
                       pstamp.im_ran(2):pstamp.im_ran(3))  
  cmp_mom,bit_ref,mom
  mk_improfile,bit_ref,prof_in,x0=mom.xc
  oplot,prof_in.r,prof_in.f,psym=1
endif

; plot residual map
window,2,title='Residuals',$
  xsize=wsize(0),ysize=wsize(1),xpos=(wsize(0)+8)*2,ypos=dsize(1)-wsize(1)
plt_image,pstamp.image-recomp,/fr,/col,title='Residuals'

; plot input image if available
if keyword_set(image_in) then begin
  ; plot input image
  window,5,title='Input image',$
    xsize=wsize(0),ysize=wsize(1),xpos=(wsize(0)+8)*2,$
    ypos=dsize(1)-2*wsize(1)-25
  bit_ref=image_in.image(pstamp.im_ran(0):pstamp.im_ran(1),$
                       pstamp.im_ran(2):pstamp.im_ran(3))
  plt_image,bit_ref,cran=c_ran,/frame,/col,$
    title='Input image'
  plt_ellipse,decomp.x(0),decomp.x(1),dmom.a,dmom.b,dmom.alpha-!pi/2.
  ; compute image moments after removing neighboring sources
  othpix= where((pstamp.seg ne 0) and (pstamp.seg ne pstamp.sexid),nothpix)  
  if nothpix gt 0 then  bit_ref(othpix)=0.
  cmp_mom,bit_ref,mom
  plt_ellipse,mom.xc(0),mom.xc(1),mom.a,mom.b,mom.alpha-!pi/2.,lines=1
  oplot,[mom.xc(0)],[mom.xc(1)],psym=1
  ; plot input parameter ellipse if input scat catalog is provided
  if keyword_set(scat_in) then begin
    centroid=shapelets_centroid(decomp)+[pstamp.im_ran(0),pstamp.im_ran(2)]
    dist_in=sqrt((scat_in.x(*,0)-centroid(0))^2+$
               (scat_in.x(*,1)-centroid(1))^2)
    dist=min(dist_in,match)
    plt_ellipse,scat_in.x(match,0)-pstamp.im_ran(0),$
              scat_in.x(match,1)-pstamp.im_ran(2),$
              scat_in.a(match)*2.,scat_in.b(match)*2.,$
              scat_in.theta(match)/!radeg-!pi/2.,lines=3
;;    print,'match: x,y:',scat_in.x(match,*)
;;    print,'match: a,b,theta:',scat_in.a(match),$
;;         scat_in.b(match),scat_in.theta(match)
  endif
endif 

end
