function shapelets_concentration,decomp,            $
                                 FLUX=flux,         $
                                 RSQUARED=rsquared, $
                                 MATRIX=matrix,     $
                                 ERROR=error,       $
                                 POLAR=polar,       $
                                 CARTESIAN=cartesian

;$Id: shapelets_concentration.pro, v2$
;
; Copyright  2004 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
;
;+
; NAME:
;      SHAPELETS_CONCENTRATION
;
; PURPOSE:
;      Returns concentration morphology index of a Cartesian decomp structure.
;
; CATEGORY:
;      Shapelets.
;
; INPUTS:
;      DECOMP - A Cartesian shapelet decomposition.
;
; KEYWORD PARAMETERS:
;      CARTESIAN - Perform summation in Cartesian shapelet space. [DEFAULT]
;      POLAR     - Perform sunnation in polar shapelet space.
;      ERROR     - Simultaneously calculate the error on the concentration.
;
; OUTPUTS:
;      CONCENTRATION - A floating point variable containing the object's
;                      concentration morphology index.
;                      If /ERROR is set, this becomes a vector
;                      [concentration,concentration_error]
;
; OPTIONAL OUTPUTS:
;      FLUX     - Flux of object (needed to calculate asymmetry anyway).
;      RSQUARED - R^2 size of object (needed to calculate asymmetry anyway).
;      MATRIX   - Cartesian to polar shapelet conversion matrix.
;
; EXAMPLE USE:
;      result = shapelets_concentration(decomp,/error)
;
; TO DO:
;      Is currently only able to calculate the simple R^2/beta morphology
;      estimator described in Shapelets: III. Should add the more complicated
;      option involving integration to various Petrosian radii.
;
; MODIFICATION HISTORY:
;      Jun 04 - Written by Richard Massey.
;-

COMPILE_OPT idl2

; Calculate R^2 size
rsqaured=shapelets_rsquared(decomp,flux=flux,error=error,cartesian=cartesian,polar=polar))

; Calculate concentration
concentration=rsquared/decomp.beta

return,concentration

end


