function shapelets_image_moments,image,printit=printit

;$Id: shapelets_image_moments.pro, v2$
;
; Copyright  2004 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
;
;+
; NAME:
;     SHAPELETS_IMAGE_MOMENTS
;
; PURPOSE:
;     Compute the zeroth (flux) and first (centroid) moment of an image.
;
; CATEGORY:
;     Image analysis.
;
; INPUTS:
;     image - 2D image array.
;
; OUTPUTS:
;     mom structure - {f: flux, xc: centroid, r: rms radius}
;
; MODIFICATION HISTORY:
;     Jul 2000 - Written by A. Refregier
;-

; make x-arrays
nf=size(image,/dimensions)
shapelets_make_xarr,nf,x1,x2,x0=[0.,0.]

; compute the flux
flux=total(image)

; compute the centroid
x1c=total(image*x1)/flux
x2c=total(image*x2)/flux

; compute the rms radius
r=sqrt(total(((x1-x1c)^2+(x2-x2c)^2)*image)/flux)

; print out results
if keyword_set(printit) then begin
  print,'flux:        ',flux
  print,'centroid:    ',x1c,x2c
  print,'rms radius r:',r
endif

; store in structure
mom={f:flux,xc:[x1c,x2c],r:r}

return,mom

end
