function shapelets_profile,decomp,r

;$Id: shapelets_profile.pro, v2$
;
; Copyright  2004 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.ast.cam.ac.uk/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License as published
; by the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
;
;+
; NAME:
;       SHAPELETS_PROFILE
;
; PURPOSE:
;       Compute the azymuthally averaged profile f(r) of an object from 
;       its shapelet coefficients.
;
; INPUTS:
;       decomp - Cartesian shapelet decomp structure
;       r      - radius at which to evaluate the profile [pixels]
;
; KEYWORD PARAMETERS:
;       None.
;
; OUTPUTS:
;       f(r) is output
;
; MODIFICATION HISTORY:
;       Mar 2002 - Written by A. Refregier
;-

; declarations
n_r=n_elements(r)
n_n=decomp.n_max/2+1
n=findgen(n_n)*2
beta=decomp.beta

; convert to polar shapelets and find f_(n,m=0) coefficients
polar_coeffs=float(shapelets_c2p(decomp.coeffs))
shapelets_make_nvec,decomp.n_max,nr,nl
nn=nr+nl
mm=nr-nl
i0=where(mm eq 0)
fn=fltarr(n_n)
fn=polar_coeffs[i0]     ; f_(n,m=0)

; compute the shapelet polar radial functions
a=fltarr(n_n,n_r)
f_rec=fltarr(n_r)
for i=0,n_n-1 do begin
  a(i,*)=(-1)^(n(i)/2.)/sqrt(!pi)/beta*$
     laguerre((r/beta)^2,n(i)/2)*exp(-.5*r^2/beta^2)
  f_rec=f_rec+fn(i)*a(i,*)
endfor

return,f_rec
end
